

'''
	balance sheet
		https://en.wikipedia.org/wiki/Balance_sheet
		
		https://www.nasdaq.com/market-activity/stocks/otly/sec-filings
		
		https://www.nasdaq.com/market-activity/stocks/otly/financials
		
		https://finance.yahoo.com/quote/OTLY/balance-sheet/
		https://stockanalysis.com/stocks/otly/financials/balance-sheet/?p=quarterly
		https://www.marketwatch.com/investing/stock/otly/financials/balance-sheet
		
		--
	
		equity
		
		---
		
		assets
		
		
		liabilities
		
		---
'''

'''


'''