


'''
	income statements
	
		
		revenue:
			
		

		expenses:
				operating expenses:
				
					might include:
						selling, general, and admin:
						research and development:
		
						other operating expenses:
		--
		
		
		net income = revenue - expenses
		
		
		--
		
		cost of revenue = 
			https://en.wikipedia.org/wiki/Cost_of_revenue
			
		cost of goods sold = 
		
		gross profit = revenue - cost of revenue
'''
