
'''
	agenda:
		import fortunes.gadgets.clock.UTC.ISO as ISO
		

'''

'''
	import datetime
	now = int (datetime.utcnow ().replace (tzinfo = timezone.utc).timestamp ())
'''

'''
	UTC_0_ISO_string = datetime.utcfromtimestamp (1609459200).isoformat ()
'''

'''
	hours ago:
		
'''

'''
	start = int (datetime.fromisoformat ("2024-01-04T00:00:00.000Z").timestamp ()),
'''

def from_UTC_timestamp ():
	return;
	
	
def to_UTC_timestamp ():
	return;