


'''
	simple moving average
		https://www.investopedia.com/terms/s/sma.asp
		https://stackoverflow.com/questions/42553891/function-for-simple-moving-average-sma?rq=4
		
		
'''

'''
	sma10 = ta.sma (DF ["close"], length=10)
'''
def calc ():
	return;