
'''
	import fortunes.gadgets.pandas.DF.from_list as df_from_list
	list = list_from_df.calc (
		df = df
	)
'''

'''
import pandas
DF = pandas.DataFrame (list)
'''

import pandas

def calc (
	list = None
):
	DF = pandas.DataFrame (list)

	return DF